Hello community,

here is the log from the commit of package asciidoc for openSUSE:Factory 
checked in at 2020-08-12 10:56:02
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/asciidoc (Old)
 and      /work/SRC/openSUSE:Factory/.asciidoc.new.3399 (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "asciidoc"

Wed Aug 12 10:56:02 2020 rev:46 rq:825216 version:9.0.2

Changes:
--------
--- /work/SRC/openSUSE:Factory/asciidoc/asciidoc.changes        2020-07-13 
09:03:48.707840644 +0200
+++ /work/SRC/openSUSE:Factory/.asciidoc.new.3399/asciidoc.changes      
2020-08-12 10:56:05.800731391 +0200
@@ -1,0 +2,6 @@
+Mon Aug  3 05:46:34 UTC 2020 - Ismail Dönmez <idon...@suse.com>
+
+- Update to version 9.0.2:
+  * Revert to using optparse from argparse for a2x
+
+-------------------------------------------------------------------

Old:
----
  asciidoc-9.0.1.tar.gz

New:
----
  asciidoc-9.0.2.tar.gz

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ asciidoc.spec ++++++
--- /var/tmp/diff_new_pack.seTLFy/_old  2020-08-12 10:56:06.416731698 +0200
+++ /var/tmp/diff_new_pack.seTLFy/_new  2020-08-12 10:56:06.416731698 +0200
@@ -17,7 +17,7 @@
 
 
 Name:           asciidoc
-Version:        9.0.1
+Version:        9.0.2
 Release:        0
 Summary:        Text-Based Document Generation
 License:        GPL-2.0-or-later

++++++ asciidoc-9.0.1.tar.gz -> asciidoc-9.0.2.tar.gz ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/asciidoc-py3-9.0.1/.github/workflows/release.yml 
new/asciidoc-py3-9.0.2/.github/workflows/release.yml
--- old/asciidoc-py3-9.0.1/.github/workflows/release.yml        2020-06-26 
21:00:25.000000000 +0200
+++ new/asciidoc-py3-9.0.2/.github/workflows/release.yml        2020-07-21 
17:02:12.000000000 +0200
@@ -36,3 +36,11 @@
           asset_path: ./build/asciidoc-${{ github.event.release.tag_name 
}}.tar.gz
           asset_name: asciidoc-${{ github.event.release.tag_name }}.tar.gz
           asset_content_type: application/gzip
+
+      - name: Update Homebrew formula
+        uses: dawidd6/action-homebrew-bump-formula@v3
+        with:
+          token: ${{secrets.BREW_TOKEN}}
+          formula: asciidoc
+          tag: ${{github.ref}}
+          revision: ${{github.sha}}
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/asciidoc-py3-9.0.1/.github/workflows/test.yml 
new/asciidoc-py3-9.0.2/.github/workflows/test.yml
--- old/asciidoc-py3-9.0.1/.github/workflows/test.yml   2020-06-26 
21:00:25.000000000 +0200
+++ new/asciidoc-py3-9.0.2/.github/workflows/test.yml   2020-07-21 
17:02:12.000000000 +0200
@@ -13,16 +13,66 @@
       python-version: 3.6
 
     steps:
-    - uses: actions/checkout@v2
+      - uses: actions/checkout@v2
 
-    - name: Set up Python ${{ matrix.python-version }}
-      uses: actions/setup-python@v1
-      with:
-        python-version: ${{ matrix.python-version }}
-
-    - name: Install Dependencies
-      run: |
-        python3 -m pip install -U pip
-        python3 -m pip install -U pytest pytest-runner flake8
-    - name: Lint codebase
-      run: python3 -m flake8
+      - name: Set up Python ${{ env.python-version }}
+        uses: actions/setup-python@v1
+        with:
+          python-version: ${{ env.python-version }}
+
+      - name: Install Dependencies
+        run: |
+          python3 -m pip install -U pip
+          python3 -m pip install -U pytest pytest-runner flake8
+
+      - name: Lint codebase
+        run: python3 -m flake8
+
+  test:
+    needs: lint
+    runs-on: ubuntu-latest
+    strategy:
+      matrix:
+        python-version: [3.5, 3.6, 3.7, 3.8, 3.9-dev]
+
+    steps:
+      - uses: actions/checkout@v2
+
+      - name: Set up Python ${{ matrix.python-version }}
+        uses: actions/setup-python@v1
+        if: "!endsWith(matrix.python-version, '-dev')"
+        with:
+          python-version: ${{ matrix.python-version }}
+      - name: Set up Python ${{ matrix.python-version }}
+        uses: deadsnakes/action@v1.0.0
+        if: endsWith(matrix.python-version, '-dev')
+        with:
+          python-version: ${{ matrix.python-version }}
+
+      - name: Install apt dependencies
+        run: |
+          sudo apt-get install -y --no-install-recommends \
+            docbook-xml \
+            docbook-xsl \
+            dvipng \
+            graphviz \
+            imagemagick \
+            libxml2-utils \
+            lilypond \
+            source-highlight \
+            texlive-latex-base \
+            xsltproc
+
+      - run: python asciidoc.py --doctest
+      - run: python asciidocapi.py
+      - run: time python tests/testasciidoc.py run
+      - run: git clean -x -f doc tests/data
+
+      - name: Test make install
+        run: |
+          autoconf
+          ./configure
+          make
+          sudo make install
+
+      - run: asciidoc --version
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/asciidoc-py3-9.0.1/.travis.yml 
new/asciidoc-py3-9.0.2/.travis.yml
--- old/asciidoc-py3-9.0.1/.travis.yml  2020-06-26 21:00:25.000000000 +0200
+++ new/asciidoc-py3-9.0.2/.travis.yml  1970-01-01 01:00:00.000000000 +0100
@@ -1,38 +0,0 @@
-language: python
-
-python:
-  - 3.5
-  - 3.6
-  - 3.7
-  - 3.8
-  - 3.9-dev
-
-jobs:
-  allow_failures:
-    - python: 3.9-dev
-
-addons:
-  apt:
-    packages:
-      - docbook-xml
-      - docbook-xsl
-      - dvipng
-      - graphviz
-      - imagemagick
-      - libxml2-utils
-      - lilypond
-      - source-highlight
-      - texlive-latex-base
-      - xsltproc
-
-install: true
-
-script:
-  - python asciidoc.py --doctest
-  - python asciidocapi.py
-  - time python tests/testasciidoc.py run
-  - git clean -x -f doc tests/data
-  - autoconf
-  - ./configure
-  - make
-  - sudo make install
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/asciidoc-py3-9.0.1/CHANGELOG.txt 
new/asciidoc-py3-9.0.2/CHANGELOG.txt
--- old/asciidoc-py3-9.0.1/CHANGELOG.txt        2020-06-26 21:00:25.000000000 
+0200
+++ new/asciidoc-py3-9.0.2/CHANGELOG.txt        2020-07-21 17:02:12.000000000 
+0200
@@ -3,6 +3,11 @@
 
 :website: https://asciidoc.org/
 
+Version 9.0.2 (2020-07-21)
+--------------------------
+.Bug fixes
+- Revert to using optparse from argparse for a2x
+
 Version 9.0.1 (2020-06-26)
 --------------------------
 .Bug fixes
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/asciidoc-py3-9.0.1/Makefile.in 
new/asciidoc-py3-9.0.2/Makefile.in
--- old/asciidoc-py3-9.0.1/Makefile.in  2020-06-26 21:00:25.000000000 +0200
+++ new/asciidoc-py3-9.0.2/Makefile.in  2020-07-21 17:02:12.000000000 +0200
@@ -262,8 +262,8 @@
 ##   dist: creates the zip and tarball for release
 .PHONY: dist
 dist: vers_update manpages MANIFEST
-       rm -rf build
        mkdir -p build
+       rm -rf build/*
        tar -czf build/asciidoc-tmp.tar.gz -T MANIFEST
        mkdir -p build/asciidoc-$(ASCIIDOCVERSION)
        tar -xf build/asciidoc-tmp.tar.gz -C build/asciidoc-$(ASCIIDOCVERSION)
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/asciidoc-py3-9.0.1/asciidoc.py 
new/asciidoc-py3-9.0.2/asciidoc.py
--- old/asciidoc-py3-9.0.1/asciidoc.py  2020-06-26 21:00:25.000000000 +0200
+++ new/asciidoc-py3-9.0.2/asciidoc.py  2020-07-21 17:02:12.000000000 +0200
@@ -33,7 +33,7 @@
 from collections import OrderedDict
 
 # Used by asciidocapi.py #
-VERSION = '9.0.1'           # See CHANGELOG file for version history.
+VERSION = '9.0.2'           # See CHANGELOG file for version history.
 
 MIN_PYTHON_VERSION = '3.5'  # Require this version of Python or better.
 
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/asciidoc-py3-9.0.1/configure.ac 
new/asciidoc-py3-9.0.2/configure.ac
--- old/asciidoc-py3-9.0.1/configure.ac 2020-06-26 21:00:25.000000000 +0200
+++ new/asciidoc-py3-9.0.2/configure.ac 2020-07-21 17:02:12.000000000 +0200
@@ -1,6 +1,6 @@
-AC_INIT(asciidoc, 9.0.1)
+AC_INIT(asciidoc, 9.0.2)
 
-AC_SUBST([PACKAGE_DATE], ['26 June 2020'])
+AC_SUBST([PACKAGE_DATE], ['21 July 2020'])
 
 AC_CONFIG_FILES(Makefile)
 


Reply via email to
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/asciidoc-py3-9.0.1/README.asciidoc 
new/asciidoc-py3-9.0.2/README.asciidoc
--- old/asciidoc-py3-9.0.1/README.asciidoc      2020-06-26 21:00:25.000000000 
+0200
+++ new/asciidoc-py3-9.0.2/README.asciidoc      2020-07-21 17:02:12.000000000 
+0200
@@ -2,7 +2,7 @@
 AsciiDoc
 ========
 
-image:https://travis-ci.com/asciidoc/asciidoc-py3.svg?branch=master["Build 
Status", link="https://travis-ci.com/asciidoc/asciidoc-py3";]
+image:https://github.com/asciidoc/asciidoc-py3/workflows/Test/badge.svg?branch=master["Build
 Status", 
link="https://github.com/asciidoc/asciidoc-py3/actions?query=workflow%3ATest+branch%3Amaster";]
 
 AsciiDoc is a text document format for writing notes, documentation,
 articles, books, ebooks, slideshows, web pages, man pages and blogs.
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/asciidoc-py3-9.0.1/a2x.py 
new/asciidoc-py3-9.0.2/a2x.py
--- old/asciidoc-py3-9.0.1/a2x.py       2020-06-26 21:00:25.000000000 +0200
+++ new/asciidoc-py3-9.0.2/a2x.py       2020-07-21 17:02:12.000000000 +0200
@@ -42,7 +42,7 @@
 import mimetypes
 
 PROG = os.path.basename(os.path.splitext(__file__)[0])
-VERSION = '9.0.1'
+VERSION = '9.0.2'
 
 # AsciiDoc global configuration file directory.
 # NOTE: CONF_DIR is "fixed up" by Makefile -- don't rename or change syntax.
@@ -892,119 +892,122 @@
 
 if __name__ == '__main__':
     description = '''A toolchain manager for AsciiDoc (converts Asciidoc text 
files to other file formats)'''
-    from argparse import ArgumentParser
-    parser = ArgumentParser(usage='usage: %(prog)s [OPTIONS] ASCIIDOC_FILE',
+    from optparse import OptionParser
+    parser = OptionParser(usage='usage: %prog [OPTIONS] SOURCE_FILE',
+        version='%s %s' % (PROG,VERSION),
         description=description)
-    parser.add_argument('--version', action='version', version='{} 
{}'.format(PROG, VERSION))
-    parser.add_argument('-a', '--attribute',
+    parser.add_option('-a', '--attribute',
         action='append', dest='attributes', default=[], metavar='ATTRIBUTE',
         help='set asciidoc attribute value')
-    parser.add_argument('--asciidoc-opts',
+    parser.add_option('--asciidoc-opts',
         action='append', dest='asciidoc_opts', default=[],
         metavar='ASCIIDOC_OPTS', help='asciidoc options')
     #DEPRECATED
-    parser.add_argument('--copy',
+    parser.add_option('--copy',
         action='store_true', dest='copy', default=False,
         help='DEPRECATED: does nothing')
-    parser.add_argument('--conf-file',
+    parser.add_option('--conf-file',
         dest='conf_file', default=None, metavar='CONF_FILE',
         help='configuration file')
-    parser.add_argument('-D', '--destination-dir',
+    parser.add_option('-D', '--destination-dir',
         action='store', dest='destination_dir', default=None, metavar='PATH',
-        help='output directory (defaults to ASCIIDOC_FILE directory)')
-    parser.add_argument('-d','--doctype',
+        help='output directory (defaults to SOURCE_FILE directory)')
+    parser.add_option('-d','--doctype',
         action='store', dest='doctype', metavar='DOCTYPE',
         choices=('article','manpage','book'),
         help='article, manpage, book')
-    parser.add_argument('-b','--backend',
+    parser.add_option('-b','--backend',
         action='store', dest='backend', metavar='BACKEND',
         help='name of backend plugin')
-    parser.add_argument('--epubcheck',
+    parser.add_option('--epubcheck',
         action='store_true', dest='epubcheck', default=False,
         help='check EPUB output with epubcheck')
-    parser.add_argument('-f','--format',
+    parser.add_option('-f','--format',
         action='store', dest='format', metavar='FORMAT', default = 'pdf',
         choices=('chunked','epub','htmlhelp','manpage','pdf', 'text',
                  'xhtml','dvi','ps','tex','docbook'),
         help='chunked, epub, htmlhelp, manpage, pdf, text, xhtml, dvi, ps, 
tex, docbook')
-    parser.add_argument('--icons',
+    parser.add_option('--icons',
         action='store_true', dest='icons', default=False,
         help='use admonition, callout and navigation icons')
-    parser.add_argument('--icons-dir',
+    parser.add_option('--icons-dir',
         action='store', dest='icons_dir',
         default=None, metavar='PATH',
         help='admonition and navigation icon directory')
-    parser.add_argument('-k', '--keep-artifacts',
+    parser.add_option('-k', '--keep-artifacts',
         action='store_true', dest='keep_artifacts', default=False,
         help='do not delete temporary build files')
-    parser.add_argument('--lynx',
+    parser.add_option('--lynx',
         action='store_true', dest='lynx', default=False,
         help='use lynx to generate text files')
-    parser.add_argument('-L', '--no-xmllint',
+    parser.add_option('-L', '--no-xmllint',
         action='store_true', dest='no_xmllint', default=False,
         help='do not check asciidoc output with xmllint')
-    parser.add_argument('-n','--dry-run',
+    parser.add_option('-n','--dry-run',
         action='store_true', dest='dry_run', default=False,
         help='just print the commands that would have been executed')
-    parser.add_argument('-r','--resource',
+    parser.add_option('-r','--resource',
         action='append', dest='resources', default=[],
         metavar='PATH',
         help='resource file or directory containing resource files')
-    parser.add_argument('-m', '--resource-manifest',
+    parser.add_option('-m', '--resource-manifest',
         action='store', dest='resource_manifest', default=None, metavar='FILE',
         help='read resources from FILE')
     #DEPRECATED
-    parser.add_argument('--resource-dir',
+    parser.add_option('--resource-dir',
         action='append', dest='resources', default=[],
         metavar='PATH',
         help='DEPRECATED: use --resource')
     #DEPRECATED
-    parser.add_argument('-s','--skip-asciidoc',
+    parser.add_option('-s','--skip-asciidoc',
         action='store_true', dest='skip_asciidoc', default=False,
         help='DEPRECATED: redundant')
-    parser.add_argument('--stylesheet',
+    parser.add_option('--stylesheet',
         action='store', dest='stylesheet', default=None,
         metavar='STYLESHEET',
         help='HTML CSS stylesheet file name')
     #DEPRECATED
-    parser.add_argument('--safe',
+    parser.add_option('--safe',
         action='store_true', dest='safe', default=False,
         help='DEPRECATED: does nothing')
-    parser.add_argument('--dblatex-opts',
+    parser.add_option('--dblatex-opts',
         action='append', dest='dblatex_opts', default=[],
         metavar='DBLATEX_OPTS', help='dblatex options')
-    parser.add_argument('--backend-opts',
+    parser.add_option('--backend-opts',
         action='append', dest='backend_opts', default=[],
         metavar='BACKEND_OPTS', help='backend plugin options')
-    parser.add_argument('--fop',
+    parser.add_option('--fop',
         action='store_true', dest='fop', default=False,
         help='use FOP to generate PDF files')
-    parser.add_argument('--fop-opts',
+    parser.add_option('--fop-opts',
         action='append', dest='fop_opts', default=[],
         metavar='FOP_OPTS', help='options for FOP pdf generation')
-    parser.add_argument('--xsltproc-opts',
+    parser.add_option('--xsltproc-opts',
         action='append', dest='xsltproc_opts', default=[],
         metavar='XSLTPROC_OPTS', help='xsltproc options for XSL stylesheets')
-    parser.add_argument('--xsl-file',
+    parser.add_option('--xsl-file',
         action='store', dest='xsl_file', metavar='XSL_FILE',
         help='custom XSL stylesheet')
-    parser.add_argument('-v', '--verbose',
+    parser.add_option('-v', '--verbose',
         action='count', dest='verbose', default=0,
         help='increase verbosity')
-    parser.add_argument("asciidoc_file", action="store", help="AsciiDoc source 
file")
+    if len(sys.argv) == 1:
+        parser.parse_args(['--help'])
     source_options = get_source_options(sys.argv[-1])
     argv = source_options + sys.argv[1:]
-    opts = parser.parse_args(argv)
+    opts, args = parser.parse_args(argv)
+    if len(args) != 1:
+        parser.error('incorrect number of arguments')
     opts.asciidoc_opts = ' '.join(opts.asciidoc_opts)
     opts.dblatex_opts = ' '.join(opts.dblatex_opts)
     opts.fop_opts = ' '.join(opts.fop_opts)
     opts.xsltproc_opts = ' '.join(opts.xsltproc_opts)
     opts.backend_opts = ' '.join(opts.backend_opts)
-    opts = vars(opts)  # Convert argparse.Values to dict.
+    opts = eval(str(opts))  # Convert optparse.Values to dict.
     a2x = A2X(opts)
     OPTIONS = a2x           # verbose and dry_run used by utility functions.
     verbose('args: %r' % argv)
-    a2x.asciidoc_file = opts['asciidoc_file']
+    a2x.asciidoc_file = args[0]
     try:
         a2x.load_conf()
         a2x.execute()